summaryrefslogtreecommitdiffstats
path: root/kdejava/koala/kdejava/KDESupport.h
diff options
context:
space:
mode:
Diffstat (limited to 'kdejava/koala/kdejava/KDESupport.h')
-rw-r--r--kdejava/koala/kdejava/KDESupport.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/kdejava/koala/kdejava/KDESupport.h b/kdejava/koala/kdejava/KDESupport.h
index 63726afd..4f0d564a 100644
--- a/kdejava/koala/kdejava/KDESupport.h
+++ b/kdejava/koala/kdejava/KDESupport.h
@@ -20,7 +20,7 @@
#include <jni.h>
-#include <qptrlist.h>
+#include <tqptrlist.h>
#include <ktrader.h>
#include <kmainwindow.h>
#include <kfile.h>
@@ -53,13 +53,13 @@ public:
/** Converts java options entries to the C++ KCmdLineOption equivalent */
static KCmdLineOptions * toKCmdLineOptions(JNIEnv * env, jobjectArray optionsArray);
- /** Converts a java.io.ByteArrayOutputStream to a QByteArray */
- static QByteArray * toQByteArrayFromStream(JNIEnv * env, QByteArray * byteArray, jobject byteStream);
+ /** Converts a java.io.ByteArrayOutputStream to a TQByteArray */
+ static TQByteArray * toQByteArrayFromStream(JNIEnv * env, TQByteArray * byteArray, jobject byteStream);
/** Returns a Java ArrayList for the various types of KDE List */
static jobject arrayWithQCStringList(JNIEnv * env, QCStringList * qcstringList);
static jobject arrayWithOfferList(JNIEnv * env, KTrader::OfferList * offerList);
- static jobject arrayWithKMainWindowList(JNIEnv * env, QPtrList<KMainWindow>* memberList);
+ static jobject arrayWithKMainWindowList(JNIEnv * env, TQPtrList<KMainWindow>* memberList);
static jobject arrayWithKFileItemList(JNIEnv * env, KFileItemList * itemList);
static jobject arrayWithKURLList(JNIEnv * env, KURL::List * kurlList);
static jobject arrayWithNodeList(JNIEnv * env, DOM::NodeList * nodeList);